==> huaweicloudsdkeip-3.1.108-py2.py3-none-any.whl: huaweicloudsdkeip/v2/model/neutron_update_floating_ip_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class NeutronUpdateFloatingIpResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'floatingip': 'PostAndPutFloatingIpResp'
    }

    attribute_map = {
        'floatingip': 'floatingip'
    }

    def __init__(self, floatingip=None):
        """NeutronUpdateFloatingIpResponse

        The model defined in huaweicloud sdk

        :param floatingip: 
        :type floatingip: :class:`huaweicloudsdkeip.v2.PostAndPutFloatingIpResp`
        """
        
        super(NeutronUpdateFloatingIpResponse, self).__init__()

        self._floatingip = None
        self.discriminator = None

        if floatingip is not None:
            self.floatingip = floatingip

    @property
    def floatingip(self):
        """Gets the floatingip of this NeutronUpdateFloatingIpResponse.

        :return: The floatingip of this NeutronUpdateFloatingIpResponse.
        :rtype: :class:`huaweicloudsdkeip.v2.PostAndPutFloatingIpResp`
        """
        return self._floatingip

    @floatingip.setter
    def floatingip(self, floatingip):
        """Sets the floatingip of this NeutronUpdateFloatingIpResponse.

        :param floatingip: The floatingip of this NeutronUpdateFloatingIpResponse.
        :type floatingip: :class:`huaweicloudsdkeip.v2.PostAndPutFloatingIpResp`
        """
        self._floatingip = floatingip

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, NeutronUpdateFloatingIpResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkeip-3.1.148-py2.py3-none-any.whl: huaweicloudsdkeip/v2/model/neutron_update_floating_ip_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class NeutronUpdateFloatingIpResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'floatingip': 'PostAndPutFloatingIpResp'
    }

    attribute_map = {
        'floatingip': 'floatingip'
    }

    def __init__(self, floatingip=None):
        r"""NeutronUpdateFloatingIpResponse

        The model defined in huaweicloud sdk

        :param floatingip: 
        :type floatingip: :class:`huaweicloudsdkeip.v2.PostAndPutFloatingIpResp`
        """
        
        super(NeutronUpdateFloatingIpResponse, self).__init__()

        self._floatingip = None
        self.discriminator = None

        if floatingip is not None:
            self.floatingip = floatingip

    @property
    def floatingip(self):
        r"""Gets the floatingip of this NeutronUpdateFloatingIpResponse.

        :return: The floatingip of this NeutronUpdateFloatingIpResponse.
        :rtype: :class:`huaweicloudsdkeip.v2.PostAndPutFloatingIpResp`
        """
        return self._floatingip

    @floatingip.setter
    def floatingip(self, floatingip):
        r"""Sets the floatingip of this NeutronUpdateFloatingIpResponse.

        :param floatingip: The floatingip of this NeutronUpdateFloatingIpResponse.
        :type floatingip: :class:`huaweicloudsdkeip.v2.PostAndPutFloatingIpResp`
        """
        self._floatingip = floatingip

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, NeutronUpdateFloatingIpResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
